%---------------------------------------------------------------
% conference GIS Ostrava - LaTeX class
% contribution class by Jan Caha, 2017
%---------------------------------------------------------------

%------------------------ class definition ---------------------
\ProvidesClass{GISOstrava}[2017/10/23 class]
\NeedsTeXFormat{LaTeX2e}

%---------------------- based on article -----------------------
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

% default optiones
\LoadClass[10pt,b5paper]{article}

% variable of vertical skip
\def\spaceSkip{6pt}

% settings of page margin
\RequirePackage[top=2cm, bottom=2cm, left=2cm, right=2cm]{geometry}

% select Nimbus Sans L as main font
\RequirePackage[scaled]{helvet}
\renewcommand*\familydefault{\sfdefault} %% Only if the base font of the document is to be sans serif
\RequirePackage[T1]{fontenc}

% settings for vspace after paragraph
\setlength{\parskip}{\spaceSkip}
% indent of paragraph
\setlength{\parindent}{10pt}
\let\@afterindenttrue\@afterindentfalse

% page numbers if we use them
\pagenumbering{arabic}

% header and footer settings
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\fancyhead[LO,LE]{\fontsize{8pt}{0pt} \color{black!50}\textsc{\textbf{GIS Ostrava 2018 - GIS for Safety \& Security Management}}}
\fancyhead[RO,RE]{\fontsize{8pt}{0pt}\color{black!50}\textsc{March 21 - 23, 2018, Ostrava}}
\lfoot{}
\cfoot{}%\cfoot{\thepage}
\rfoot{}
\renewcommand{\headrule}{\hbox to\headwidth{%
    \color{black!50}\leaders\hrule height \headrulewidth\hfill}}
\renewcommand{\headrulewidth}{0.5pt}
% all pages with header and footer
\fancypagestyle{plain}{%
  \pagestyle{fancy}
}

% settings making LaTeX sensitive to one-line paragraphs on end and begining of pages 
\widowpenalty=5000
\clubpenalty=5000

% rename of section 
\newcommand\referenceName{REFERENCES}

% author and institution styling
\RequirePackage{authblk}
\renewcommand*{\Authsep}{; }
\renewcommand*{\Authand}{; }
\renewcommand*{\Authands}{; }
\setlength{\affilsep}{1em}
\renewcommand\Authfont{\fontsize{11}{13.2}\selectfont}
\renewcommand\Affilfont{\fontsize{10}{12}\selectfont}

% title of page styling
\renewcommand\maketitle{
	\newpage
	\begin{center}
		{{\fontsize{11}{13.2}\selectfont \textbf \@title}} 
		\vskip \spaceSkip
		
		{		
		\begin {tabular}[t]{c}
			\@author 
		\end {tabular}
		\par 
		}
		
	\end{center}
}

% turn of numbering of sections and subsections
\setcounter{secnumdepth}{0}

% package and styling of the sections and subsections titles 
\RequirePackage{titlesec}
\titlespacing{\section}{0pt}{18pt}{0pt}
\titlespacing{\subsection}{0pt}{12pt}{0pt}
\titleformat{\section}{\normalfont\fontsize{10}{12}\bfseries}{\thesection}{}{}
\titleformat{\subsection}{\normalfont\fontsize{10}{12}\bfseries}{\thesection}{}{}

% package and settings for citation
\RequirePackage[abbr]{harvard}
\renewcommand{\harvardand}{and}
\renewcommand{\harvardurl}{Available from: }

% package and styling of lists
\RequirePackage{enumitem}
\setlist[itemize]{leftmargin=1cm}

% package for correct coding of resulting PDF
\RequirePackage[utf8]{inputenc}
\RequirePackage{cmap}

% math packages
\RequirePackage{amsthm}
\RequirePackage{amsbsy}
\RequirePackage{amssymb}
\RequirePackage{amsfonts}
\RequirePackage[fleqn]{amsmath}
\RequirePackage{bbm}
\setlength{\mathindent}{1cm}

% captions package
\RequirePackage[center, labelsep=period, labelfont=bf]{caption}

% color packages
\RequirePackage[usenames,dvipsnames]{color}
\RequirePackage{xcolor}

% references packaga
\RequirePackage[citebordercolor={1 1 1}, linkbordercolor={1 1 1}, urlbordercolor={1 1 1}]{hyperref}
\renewcommand{\tableautorefname}{Tab.}
\renewcommand{\figureautorefname}{Fig.}

% packages for table styling 
\RequirePackage{booktabs}
\RequirePackage{dcolumn}
\RequirePackage{multirow}


% package for more specific definition of float objects
\RequirePackage{float}
% package that allows using adjacent images
\RequirePackage{subcaption}

% english dictonary
\RequirePackage[english]{babel}
\addto\captionsenglish{\renewcommand{\figurename}{Fig.}}
\addto\captionsenglish{\renewcommand{\tablename}{Table}}

% packages for graphics
\RequirePackage[pdftex]{graphicx}
\RequirePackage{epstopdf}

% package for SI units
\RequirePackage{siunitx}

% packages for pseudoalgorithms and codes
\RequirePackage{algpseudocode}
\RequirePackage{algorithm}
\RequirePackage{algorithmicx}
\RequirePackage{listings}
\RequirePackage{courier}
\lstset{basicstyle=\footnotesize\ttfamily,breaklines=true}
\renewcommand{\lstlistingname}{Algorithm}
\providecommand*{\lstlistingautorefname}{Alg.}



%-------------------------- new enviroments for abstract and keywords -----------------------
\renewenvironment{abstract}{\noindent \textbf{Abstract} \vspace{\spaceSkip} \\}{}
\newenvironment{keywords}{\noindent \textbf{Keywords:}}{}